import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.time.LocalDateTime;
import java.util.logging.Level;
import java.util.logging.Logger;
import oracle.ucp.jdbc.PoolDataSource;
import oracle.ucp.jdbc.PoolDataSourceFactory;

public class UCPLogTest {
	private static final Logger LOGGER = Logger.getLogger(UCPLogTest.class.getName());
	private static final String CONN_FACTORY_CLASS_NAME = "oracle.jdbc.pool.OracleDataSource";
	private static final String DB_URL = "jdbc:oracle:thin:@//localhost:1521/orcl";
	private static final String DB_USER = "scott";
	private static final String DB_PASSWORD = "tiger";
	private static final String QUERY = "select sessiontimezone, localtimestamp from dual";

	public void test() {
		final PoolDataSource pds = PoolDataSourceFactory.getPoolDataSource();
		try {
			pds.setConnectionFactoryClassName(CONN_FACTORY_CLASS_NAME);
			pds.setURL(DB_URL);
			pds.setUser(DB_USER);
			pds.setPassword(DB_PASSWORD);

			try (final Connection conn = pds.getConnection()) {
				try (final Statement stmt = conn.createStatement(); final ResultSet rs = stmt.executeQuery(QUERY)) {
					rs.next();
					LOGGER.log(Level.INFO, "sessiontimezone: {0}", rs.getObject(1, String.class));
					LOGGER.log(Level.INFO, "localtimestamp: {0}", rs.getObject(2, LocalDateTime.class));
				} catch (SQLException e) {
					LOGGER.log(Level.SEVERE, "Failed to execute the query", e);
					System.exit(3);
				}
			} catch (SQLException e) {
				LOGGER.log(Level.SEVERE, "Failed to connect", e);
				System.exit(2);
			}
		} catch (SQLException e) {
			LOGGER.log(Level.SEVERE, "Failed to set up the pool", e);
			System.exit(1);
		}
	}
}
